@@ -5,6 +5,7 @@ from .pipeable import pipeable
 def map(f, L):
     ''' applies f to all elements of L, immediately returning a list of the resulting values.
 
+    Equivalent to [f(x) for x in L]
     Args:
         f: A unary function
         L: A list of values
@@ -12,10 +13,38 @@ def map(f, L):
     Returns:
         A list of the results of f applied to each element of L.
         Note that this is a strict version of the built-in map (which returns a generator).
+
+    >>> from composable.strict import map
+    >>> range(3) >> map(lambda x: x + 5)
+    [5, 6, 7]
     '''
     return [f(x) for x in L]
 
 
+@pipeable
+def star_map(f, L):
+    ''' applies f after unpacking the elements of L as positional arguments, immediately returning a list of the resulting values.
+
+    Equivalent to [f(*args) for args in L] 
+    Args:
+        f: A function taking one or more positional arguments
+        L: A list of tuples of values to be unpacked when calling f
+
+    Returns:
+        A list of the results of f applied to each element of L.
+        Note that this is a strict version of the built-in map (which returns a generator).
+
+    >>> from composable.strict import star_map
+    >>> from operator import add
+    >>> vals = list(zip(range(5), range(2, 7)))
+    >>> vals
+    [(0, 2), (1, 3), (2, 4), (3, 5), (4, 6)]
+    >>> vals >> star_map(add)
+    [2, 4, 6, 8, 10]
+    '''
+    return [f(*args) for args in L]
+
+
 @pipeable
 def filter(p, L):
     ''' Filters the elements of L, returning a list of all elements that pass the predicate p.
